@@ -14,6 +14,8 @@ SCREENSHOT_DIR = os.path.join(GLib.get_user_cache_dir(), "mintinstall", "screens
 
 MAX_AGE = 14 * (60 * 60 * 24) # days
 
+proc = None
+
 def run():
     print("MintInstall: Deleting old screenshots")
 
@@ -21,11 +23,15 @@ def run():
     thread.start()
 
 def _clean_screenshots_thread():
-    proc = multiprocessing.Process(target=_clean_screenshots_process)
+    global proc
 
+    proc = multiprocessing.Process(target=_clean_screenshots_process)
     proc.start()
+
     proc.join()
 
+    proc = None
+
 def _clean_screenshots_process():
     ss_location = Path(SCREENSHOT_DIR)
 
@@ -33,10 +39,18 @@ def _clean_screenshots_process():
 
     for p in screenshots:
         try:
-            mtime = os.path.getmtime(p)
+            mtime = os.path.getmtime(str(p))
 
             if (time.time() - MAX_AGE) > mtime:
                 p.unlink()
         except OSError:
             pass
 
+def kill():
+    global proc
+
+    try:
+        proc.terminate()
+        proc = None
+    except AttributeError as e:
+        pass
