@@ -69,7 +69,7 @@ SCREENSHOT_DIR = os.path.join(GLib.get_user_cache_dir(), "mintinstall", "screens
 ALIASES = {}
 ALIASES['spotify-client'] = "Spotify"
 ALIASES['steam-launcher'] = "Steam"
-ALIASES['minecraft-installer'] = "Minecraft"
+ALIASES['minecraft-launcher'] = "Minecraft"
 ALIASES['virtualbox-qt'] = "Virtualbox " # Added a space to force alias
 ALIASES['virtualbox'] = "Virtualbox (base)"
 ALIASES['sublime-text'] = "Sublime"
@@ -1114,6 +1114,7 @@ class Application(Gtk.Application):
                 self.show_package(self.current_pkginfo, self.previous_page)
             else:
                 del self.installer.cache[pkginfo.pkg_hash]
+                self.previous_page = self.PAGE_LANDING
                 self.go_back_action()
 
         for tile in (self.picks_tiles + self.category_tiles):
@@ -1324,7 +1325,7 @@ class Application(Gtk.Application):
 
         self.installer = installer.Installer()
 
-        from installer import cache
+        from mintcommon.installer import cache
 
         self.installer.cache = cache.PkgCache(self.installer.have_flatpak)
         self.installer.force_new_cache()
@@ -1350,7 +1351,11 @@ class Application(Gtk.Application):
             description = description.replace("\n", "<br>")
 
             summary = self.installer.get_summary(pkginfo)
-            url = self.installer.get_url(pkginfo)
+            url = ""
+            try:
+                url = self.installer.get_url(pkginfo)
+            except:
+                pass
 
             categories = []
             for category in pkginfo.categories:
@@ -2088,7 +2093,10 @@ class Application(Gtk.Application):
         app_description.set_label(description)
         app_description.set_line_wrap(True)
 
-        homepage = self.installer.get_url(pkginfo)
+        try:
+            homepage = self.installer.get_url(pkginfo)
+        except:
+            homepage = None
         if homepage is not None and homepage != "":
             self.builder.get_object("website_link").show()
             self.builder.get_object("website_link").set_markup("<a href='%s'>%s</a>" % (homepage, homepage))
